@@ -376,3 +376,222 @@ def test_naturaltime_minimum_unit_explicit(minimum_unit, seconds, expected):
 
     # Act / Assert
     assert humanize.naturaltime(delta, minimum_unit=minimum_unit) == expected
+
+
+@pytest.mark.parametrize(
+    "val, min_unit, expected",
+    [
+        (dt.timedelta(microseconds=1), "microseconds", "1 microsecond"),
+        (dt.timedelta(microseconds=2), "microseconds", "2 microseconds"),
+        (dt.timedelta(microseconds=1000), "microseconds", "1 millisecond"),
+        (dt.timedelta(microseconds=2000), "microseconds", "2 milliseconds"),
+        (dt.timedelta(seconds=1), "seconds", "1 second"),
+        (1, "seconds", "1 second"),
+        (2, "seconds", "2 seconds"),
+        (60, "seconds", "1 minute"),
+        (120, "seconds", "2 minutes"),
+        (3600, "seconds", "1 hour"),
+        (3600 * 2, "seconds", "2 hours"),
+        (3600 * 24, "seconds", "1 day"),
+        (3600 * 24 * 2, "seconds", "2 days"),
+        (3600 * 24 * 365, "seconds", "1 year"),
+        (3600 * 24 * 365 * 2, "seconds", "2 years"),
+    ],
+)
+def test_precisedelta_one_unit_enough(val, min_unit, expected):
+    assert humanize.precisedelta(val, minimum_unit=min_unit) == expected
+
+
+@pytest.mark.parametrize(
+    "val, min_unit, expected",
+    [
+        (
+            dt.timedelta(microseconds=1001),
+            "microseconds",
+            "1 millisecond and 1 microsecond",
+        ),
+        (
+            dt.timedelta(microseconds=2002),
+            "microseconds",
+            "2 milliseconds and 2 microseconds",
+        ),
+        (
+            dt.timedelta(seconds=1, microseconds=2),
+            "microseconds",
+            "1 second and 2 microseconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=3, microseconds=2),
+            "microseconds",
+            "4 hours, 3 seconds and 2 microseconds",
+        ),
+        (
+            dt.timedelta(days=5, hours=4, seconds=3, microseconds=2),
+            "microseconds",
+            "5 days, 4 hours, 3 seconds and 2 microseconds",
+        ),
+        (
+            dt.timedelta(days=370, hours=4, seconds=3, microseconds=2),
+            "microseconds",
+            "1 year, 5 days, 4 hours, 3 seconds and 2 microseconds",
+        ),
+        (
+            dt.timedelta(days=370, microseconds=2),
+            "microseconds",
+            "1 year, 5 days and 2 microseconds",
+        ),
+        (
+            dt.timedelta(days=370, seconds=2),
+            "microseconds",
+            "1 year, 5 days and 2 seconds",
+        ),
+    ],
+)
+def test_precisedelta_multiple_units(val, min_unit, expected):
+    assert humanize.precisedelta(val, minimum_unit=min_unit) == expected
+
+
+@pytest.mark.parametrize(
+    "val, min_unit, fmt, expected",
+    [
+        (
+            dt.timedelta(microseconds=1001),
+            "milliseconds",
+            "%0.4f",
+            "1.0010 milliseconds",
+        ),
+        (
+            dt.timedelta(microseconds=2002),
+            "milliseconds",
+            "%0.4f",
+            "2.0020 milliseconds",
+        ),
+        (dt.timedelta(microseconds=2002), "milliseconds", "%0.2f", "2.00 milliseconds"),
+        (
+            dt.timedelta(seconds=1, microseconds=230000),
+            "seconds",
+            "%0.2f",
+            "1.23 seconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=3, microseconds=200000),
+            "seconds",
+            "%0.2f",
+            "4 hours and 3.20 seconds",
+        ),
+        (
+            dt.timedelta(days=5, hours=4, seconds=30 * 60),
+            "seconds",
+            "%0.2f",
+            "5 days, 4 hours and 30 minutes",
+        ),
+        (
+            dt.timedelta(days=5, hours=4, seconds=30 * 60),
+            "hours",
+            "%0.2f",
+            "5 days and 4.50 hours",
+        ),
+        (dt.timedelta(days=5, hours=4, seconds=30 * 60), "days", "%0.2f", "5.19 days"),
+        (dt.timedelta(days=120), "months", "%0.2f", "3.93 months"),
+        (dt.timedelta(days=183), "years", "%0.1f", "0.5 years"),
+    ],
+)
+def test_precisedelta_custom_format(val, min_unit, fmt, expected):
+    assert humanize.precisedelta(val, minimum_unit=min_unit, format=fmt) == expected
+
+
+@pytest.mark.parametrize(
+    "val, min_unit, suppress, expected",
+    [
+        (
+            dt.timedelta(microseconds=1200),
+            "microseconds",
+            [],
+            "1 millisecond and 200 microseconds",
+        ),
+        (
+            dt.timedelta(microseconds=1200),
+            "microseconds",
+            ["milliseconds"],
+            "1200 microseconds",
+        ),
+        (
+            dt.timedelta(microseconds=1200),
+            "microseconds",
+            ["microseconds"],
+            "1.20 milliseconds",
+        ),
+        (
+            dt.timedelta(seconds=1, microseconds=200),
+            "microseconds",
+            ["seconds"],
+            "1000 milliseconds and 200 microseconds",
+        ),
+        (
+            dt.timedelta(seconds=1, microseconds=200000),
+            "microseconds",
+            ["milliseconds"],
+            "1 second and 200000 microseconds",
+        ),
+        (
+            dt.timedelta(seconds=1, microseconds=200000),
+            "microseconds",
+            ["milliseconds", "microseconds"],
+            "1.20 seconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=30, microseconds=200),
+            "microseconds",
+            ["microseconds"],
+            "4 hours, 30 seconds and 0.20 milliseconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=30, microseconds=200),
+            "microseconds",
+            ["seconds"],
+            "4 hours, 30000 milliseconds and 200 microseconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=30, microseconds=200),
+            "microseconds",
+            ["seconds", "milliseconds"],
+            "4 hours and 30000200 microseconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=30, microseconds=200),
+            "microseconds",
+            ["hours"],
+            "240 minutes, 30 seconds and 200 microseconds",
+        ),
+        (
+            dt.timedelta(hours=4, seconds=30, microseconds=200),
+            "microseconds",
+            ["hours", "seconds", "milliseconds", "microseconds"],
+            "240.50 minutes",
+        ),
+    ],
+)
+def test_precisedelta_suppress_units(val, min_unit, suppress, expected):
+    assert (
+        humanize.precisedelta(val, minimum_unit=min_unit, suppress=suppress) == expected
+    )
+
+
+def test_precisedelta_bogus_call():
+    assert humanize.precisedelta(None) is None
+
+    with pytest.raises(ValueError):
+        humanize.precisedelta(1, minimum_unit="years", suppress=["years"])
+
+    with pytest.raises(ValueError):
+        humanize.naturaldelta(1, minimum_unit="years")
+
+
+def test_time_unit():
+    years, minutes = time.Unit["YEARS"], time.Unit["MINUTES"]
+    assert minutes < years
+    assert years > minutes
+    assert minutes == minutes
+
+    with pytest.raises(TypeError):
+        years < "foo"
